#	Generate a vplot file that draws triangle grid
#
#	vptrigrid.x par=trigrid.p out=trigrid.v 
#
# FILES:
#	INPUT:	
#	OUTPUT:
#		stdout:	vplot file
#		
# PARAMETERS:
#	FROM INPUT:
#	FROM PAR:
#		xll,yll,xur,yur the true coordinates of the vplot
#		plotcol=6 	color of plot
#		plotfat=1	fat of plot
#		wantframe=1	=0 no frame; =1 frame
#		detail=1	=0 no detail; =1 show detail
#				
#
# NOTE:
#% end of self doc
#
#-------------
# keyword: dmo geometry
#-------------

integer narray

from par:	integer narray=11

allocate:	real xx(narray),zz(narray)

subroutine submain(narray,xx,zz)

integer nz,nx,neconst,iz,ix
integer narray,iarray
integer plotcol,plotfat,titlesz,titlefat,fat
integer wantframe,detail
integer outfd, output
real z0,x0,dz,dx
real xll,yll,xur,yur
real xmin,zmin,xmax,zmax,xrange,zrange,zxrange
real xcenter,zcenter,xscale,zscale
real x,z,x1,z1,x2,z2
real theta,y,h0,dh
real xx(narray),zz(narray)
character*50 out
character*50 title

# PARAMETERS
#    INPUT 
	from par:	integer n1:nz=7,n2:nx=13
	from par:	integer neconst=4
	from par:	integer plotcol=6,plotfat=1,titlesz=12,titlefat=5
	from par:	integer wantframe=1,detail=1
	from par:	real xll=1.705,yll=2.903,xur=11.945,yur=7.337
	from par:	real o1:z0=0.,o2:x0=0.,d1:dz=0.00866,d2:dx=0.01
	from par:	real theta=45.,y=0.5,h0=0.,dh=0.1
	from par:	character title=" "

#    OUTPUT

# CHECK

# FILES
#   INPUT

#   OUTPUT
	outfd = output()
	if(getch('out','s',out) == 0)
	   call vpfilep(outfd)
	else
	   call vpfile(out)

	call hclose()

# CALCULATION 
	#set parameters
	xmin = x0
	zmin = z0
	xmax = x0+(nx-1)*dx
	zmax = z0+(nz-1)*dz
	xcenter=0.5*(xmin+xmax)
	zcenter=0.5*(zmin+zmax)
	xrange = xmax-xmin
	zrange = zmax-zmin
	zxrange = sqrt(xrange*xrange+zrange*zrange)

	# set vplot scales
	call vporig(xll,yur)
	call vpuorig(xmin,zmin)
        xscale = (xur-xll)/(xmax-xmin)
        zscale = -(yur-yll)/(zmax-zmin)
	call vpscale(xscale,zscale)

# draw a triangle grid
	call vpcolor(7)
	call vpfat(plotfat)
	do iz = 1,nz
	{
	   z = z0+(iz-1)*dz
	   z1 = z
	   z2 = z
	   if(mod(iz,2) != 0)
	   {
	      x1 = x0
	      x2 = x0+(nx-1)*dx
	   }
	   else
	   {
	      x1 = x0+0.5*dx
	      x2 = x0+(nx-1)*dx-0.5*dx
	   }
	   call vpumove(x1,z1)
	   call vpudraw(x2,z2)
	}
	do iz = 1,nz-1
	{
	   z = z0+(iz-1)*dz
	   if(mod(iz,2) != 0)
	   {
	      do ix = 1,nx-1
	      {
	         x = x0+(ix-1)*dx
	         x1 = x
	         z1 = z
	         call vpumove(x1,z1)
	         x1 = x+0.5*dx
	         z1 = z+dz
	         call vpudraw(x1,z1)
	         x1 = x+dx
	         z1 = z
	         call vpudraw(x1,z1)
	      }
	   }
	   else
	   {
	      do ix = 1,nx-1
	      {
	         x = x0+(ix-1)*dx+0.5*dx
	         x1 = x-0.5*dx
	         z1 = z+dz
	         call vpumove(x1,z1)
	         x1 = x
	         z1 = z
	         call vpudraw(x1,z1)
	         x1 = x+0.5*dx
	         z1 = z+dz
	         call vpudraw(x1,z1)
	      }
	   }
	}

# draw grid points
	do iz = 1,nz
	{
	   z = z0+(iz-1)*dz
	   if(mod(iz,2) != 0)
	   {
	      do ix = 1,nx
	      {
	         x = x0+(ix-1)*dx
	         do iarray = 1,narray
	         {
	            theta = (iarray-1)*8*atan(1.)/(narray-1)
	            xx(iarray) = x+0.008*zxrange*sin(theta)
	            zz(iarray) = z+0.008*zxrange*cos(theta)
	         }
	         call vpcolor(0)
	         call vpufill(xx,zz,narray)
	         call vpcolor(7)
	         fat = 4*plotfat
	         call vpfat(fat)
	         call vpupline(xx,zz,narray)
	      }
	   }
	   else
	   {
	      do ix = 1,nx-1
	      {
	         x = x0+(ix-1)*dx+0.5*dx
	         do iarray = 1,narray
	         {
	            theta = (iarray-1)*8*atan(1.)/(narray-1)
	            xx(iarray) = x+0.008*zxrange*sin(theta)
	            zz(iarray) = z+0.008*zxrange*cos(theta)
	         }
	         call vpcolor(0)
	         call vpufill(xx,zz,narray)
	         call vpcolor(7)
	         fat = 4*plotfat
	         call vpfat(fat)
	         call vpupline(xx,zz,narray)
	      }
	   }
	}

# draw the big triangle
	if(detail == 1)
	{
	   xx(1) = x0+7.5*dx
	   zz(1) = z0+dz
	   xx(2) = x0+7.*dx
	   zz(2) = z0+2.*dz
	   xx(3) = x0+8.*dx
	   zz(3) = z0+2.*dz
	   xx(4) = x0+7.5*dx
	   zz(4) = z0+dz
	   call vpcolor(0)
	   call vpufill(xx,zz,4)
	   call vpcolor(5)
	   fat = plotfat
	   call vpfat(fat)
	   call vpupline(xx,zz,4)
	   x = x0+7.5*dx
	   z = z0+dz
	   do iarray = 1,narray
	   {
	      theta = (iarray-1)*8*atan(1.)/(narray-1)
	      xx(iarray) = x+0.008*zxrange*sin(theta)
	      zz(iarray) = z+0.008*zxrange*cos(theta)
	   }
	   call vpcolor(5)
	   call vpufill(xx,zz,narray)
	   call vpcolor(5)
	   fat = 4*plotfat
	   call vpfat(fat)
	   call vpupline(xx,zz,narray)
	   x = x0+7.*dx
	   z = z0+2.*dz
	   do iarray = 1,narray
	   {
	      theta = (iarray-1)*8*atan(1.)/(narray-1)
	      xx(iarray) = x+0.008*zxrange*sin(theta)
	      zz(iarray) = z+0.008*zxrange*cos(theta)
	   }
	   call vpcolor(5)
	   call vpufill(xx,zz,narray)
	   call vpcolor(5)
	   fat = 4*plotfat
	   call vpfat(fat)
	   call vpupline(xx,zz,narray)
	   x = x0+8.*dx
	   z = z0+2.*dz
	   do iarray = 1,narray
	   {
	      theta = (iarray-1)*8*atan(1.)/(narray-1)
	      xx(iarray) = x+0.008*zxrange*sin(theta)
	      zz(iarray) = z+0.008*zxrange*cos(theta)
	   }
	   call vpcolor(5)
	   call vpufill(xx,zz,narray)
	   call vpcolor(5)
	   fat = 4*plotfat
	   call vpfat(fat)
	   call vpupline(xx,zz,narray)
	   xx(1) = x0+2.5*dx
	   zz(1) = z0+2*dz
	   xx(2) = x0+0.75*dx
	   zz(2) = z0+5.5*dz
	   xx(3) = x0+4.25*dx
	   zz(3) = z0+5.5*dz
	   xx(4) = x0+2.5*dx
	   zz(4) = z0+2*dz
	   call vpcolor(5)
	   fat = 4*plotfat
	   call vpfat(fat)
	   call vpdash(0.2,0.2,0.2,0.2)
	   x1 = xx(1)
	   z1 = zz(1)
	   call vpumove(x1,z1)
	   x1 = x0+7.5*dx
	   z1 = z0+dz
	   call vpudraw(x1,z1)
	   x1 = xx(2)
	   z1 = zz(2)
	   call vpumove(x1,z1)
	   x1 = x0+7.*dx
	   z1 = z0+2.*dz
	   call vpudraw(x1,z1)
	   x1 = xx(3)
	   z1 = zz(3)
	   call vpumove(x1,z1)
	   x1 = x0+8.*dx
	   z1 = z0+2.*dz
	   call vpudraw(x1,z1)
	   call vpdash(0.,0.,0.,0.)
	   call vpcolor(0)
	   call vpufill(xx,zz,4)
	   call vpcolor(5)
	   fat = 8*plotfat
	   call vpfat(fat)
	   call vpupline(xx,zz,4)
	   x = x0+2.5*dx
	   z = z0+2.*dz
	   do iarray = 1,narray
	   {
	      theta = (iarray-1)*8*atan(1.)/(narray-1)
	      xx(iarray) = x+0.01*zxrange*sin(theta)
	      zz(iarray) = z+0.01*zxrange*cos(theta)
	   }
	   call vpcolor(5)
	   call vpufill(xx,zz,narray)
	   call vpcolor(5)
	   fat = 6*plotfat
	   call vpfat(fat)
	   call vpupline(xx,zz,narray)
	   x = x0+0.75*dx
	   z = z0+5.5*dz
	   do iarray = 1,narray
	   {
	      theta = (iarray-1)*8*atan(1.)/(narray-1)
	      xx(iarray) = x+0.01*zxrange*sin(theta)
	      zz(iarray) = z+0.01*zxrange*cos(theta)
	   }
	   call vpcolor(5)
	   call vpufill(xx,zz,narray)
	   call vpcolor(5)
	   fat = 6*plotfat
	   call vpfat(fat)
	   call vpupline(xx,zz,narray)
	   x = x0+4.25*dx
	   z = z0+5.5*dz
	   do iarray = 1,narray
	   {
	      theta = (iarray-1)*8*atan(1.)/(narray-1)
	      xx(iarray) = x+0.01*zxrange*sin(theta)
	      zz(iarray) = z+0.01*zxrange*cos(theta)
	   }
	   call vpcolor(5)
	   call vpufill(xx,zz,narray)
	   call vpcolor(5)
	   fat = 6*plotfat
	   call vpfat(fat)
	   call vpupline(xx,zz,narray)
#	   call vptfont(-1,-1,2)
	   call vpcolor(3)
	   call vpfat(4)
	   call vptjust(2,3)
	   x1 = x0+0.4*dx
	   z1 = z0+5.6*dz
	   call vputext(x1,z1,10,0,'a')
	   x1 = x0+2.5*dx
	   z1 = z0+1.55*dz
	   call vputext(x1,z1,10,0,'b')
	   x1 = x0+4.6*dx
	   z1 = z0+5.6*dz
	   call vputext(x1,z1,10,0,'o')
	}

# write title
	call vpcolor(7)
	call vpfat(titlefat)
        call vptjust(2,1)
        x = xcenter
        z = zmin-0.008*titlesz*zxrange
        call vputext(x,z,titlesz,0,title)

# draw a frame
	if(wantframe != 0.)
	{
	   call vpcolor(7)
	   call vpfat(1)
#	   call vpumove(xmin,zmin)
#	   call vpudraw(xmin,zmax)
#	   call vpudraw(xmax,zmax)
#	   call vpudraw(xmax,zmin)
#	   call vpudraw(xmin,zmin)
	}
	   
stop
end
