#
# 	Program generates a vplot file that draws the figure illustrating
#	wavefront propagation by local ray-tracing method
#
#	vpwftprg1 par=parfile out=file.v > file.V
#
# FILES:
#	INPUT:	
#	OUTPUT:
#		stdout:	vplot file
#		
# PARAMETERS:
#	FROM INPUT:
#	FROM PAR:
#		xll,yll,xur,yur the true coordinates of the vplot
#		plotcol=6 	color of plot
#		plotfat=1	fat of plot
#		wantframe=1	=0 no frame; =1 frame
#				
#
# NOTE:
#% end of self doc
#
#-------------
# keyword:
#-------------

integer narray

from par:	integer narray=11

nary = 8

allocate:	real xx(narray),zz(narray)
allocate:	real arya(nary),aryb(nary),aryc(nary),ary0(nary)

subroutine submain(narray,nary,xx,zz,arya,aryb,aryc,ary0)

integer narray,iarray,nary,iary,chk0
integer plotcol,plotfat,titlesz,titlefat,fat
integer wantframe
integer outfd, output
real xll,yll,xur,yur
real xmin,zmin,xmax,zmax,xrange,zrange,zxrange
real xcenter,zcenter,xscale,zscale
real vs,vx,vz,v0,x0,z0,dx,dz
real xa,za,xb,zb,xc,zc,xs,zs
real va,vb,vc,vs
real x,z,theta,dscale
real arya(nary),aryb(nary),aryc(nary),ary0(nary)
real xx(narray),zz(narray)
character*50 out
character*50 title
character*73 longstr

# PARAMETERS
#    INPUT 
	from par:	integer plotcol=6,plotfat=1,titlesz=12,titlefat=5
	from par:	integer wantframe=1
	from par:	real xll=2.495,yll=1.37,xur=11.155,yur=8.87
	from par:	character title=" "
	from par:	real dx=0.01,dz=0.00866
	from par:	real vs=1.,vx=0.,vz=0.
	from par:	real x0=1.,z0=1.
	from par:	real v0=vs+vx*x0+vz*z0

#   OUTPUT
	to history:		real xll,yll,xur,yur

# FILES

#   INPUT
#	no input

#   OUTPUT
	outfd = output()
	if(getch('out','s',out) == 0)
	   call vpfilep(outfd)
	else
	   call vpfile(out)

# CHECK
# 	no check

	call vperase()
	call hclose()

# STARTING PROGRAM
        # normalization of parameters
        dscale = max(dx,dz)
        z0 = z0/dscale
        x0 = x0/dscale
        dx = dx/dscale
        dz = dz/dscale
	vs = vs/dscale
	v0 = v0/dscale
	#set parameters
	xmin = -dx
	zmin = -dz
	xmax = dx
	zmax = dz
	xcenter=0.5*(xmin+xmax)
	zcenter=0.5*(zmin+zmax)
	xrange = xmax-xmin
	zrange = zmax-zmin
	zxrange = sqrt(xrange*xrange+zrange*zrange)

	# set vplot scales
	x = 0.5*(xll+xur)
	z = 0.5*(yll+yur)
	call vporig(x,z)
	call vpuorig(0.,0.)
        xscale = (xur-xll)/(xmax-xmin)
        zscale = -(yur-yll)/(zmax-zmin)
	call vpscale(xscale,zscale)

# initializtion
	xs = -x0
	zs = -z0
	vs = vs
	if(vs <= 0.) 
	   call erexit('vs is negative')
	xa = -dx
	za = 0.
	va = vs+vx*(xa-xs)+vz*(za-zs)
	if(va <= 0.) 
	   call erexit('va is negative')
	call cgvtwurthjj(va,vs,vz,vx,za,xa,zs,xs,arya(1),arya(2),
	                 arya(3),arya(4),arya(5),arya(8))
	xb = -0.5*dx
	zb = -dz
	vb = vs+vx*(xb-xs)+vz*(zb-zs)
	if(va <= 0.) 
	   call erexit('vb is negative')
	call cgvtwurthjj(vb,vs,vz,vx,zb,xb,zs,xs,aryb(1),aryb(2),
	                 aryb(3),aryb(4),aryb(5),aryb(8))
	xc = 0.5*dx
	zc = -dz
	vc = vs+vx*(xc-xs)+vz*(zc-zs)
	if(va <= 0.) 
	   call erexit('vc is negative')
	call cgvtwurthjj(vc,vs,vz,vx,zc,xc,zs,xs,aryc(1),aryc(2),
	                 aryc(3),aryc(4),aryc(5),aryc(8))
	arya(6) = arya(5)
	arya(7) = aryb(5)
	aryb(6) = arya(5)
	aryb(7) = aryc(5)
	aryc(6) = aryb(5)
	aryc(7) = aryc(5)

# draw triangle grid
	call vpdash(0.1,0.2,0.1,0.2)
	call vpcolor(7)
	fat = 2.*plotfat
	call vpfat(fat)
	x = -dx
	z = 0.
	call vpumove(x,z)
	x = dx
	z = 0.
	call vpudraw(x,z)
	x = -0.5*dx
	z = dz
	call vpumove(x,z)
	x = 0.5*dx
	z = -dz
	call vpudraw(x,z)
	x = -0.5*dx
	z = -dz
	call vpumove(x,z)
	x = 0.5*dx
	z = dz
	call vpudraw(x,z)
	x = -dx
	z = 0.
	call vpumove(x,z)
	x = -0.5*dx
	z = dz
	call vpudraw(x,z)
	x = 0.5*dx
	z = dz
	call vpudraw(x,z)
	x = dx
	z = 0.
	call vpudraw(x,z)
	x = 0.5*dx
	z = -dz
	call vpudraw(x,z)
	x = -0.5*dx
	z = -dz
	call vpudraw(x,z)
	x = -dx
	z = 0.
	call vpudraw(x,z)
	call vpdash(0.,0.,0.,0.)
	call vpcolor(6)
	fat = 4.*plotfat
	call vpfat(fat)
	x = 0.
	z = 0.
	call vpumove(x,z)
	x = -dx
	z = 0.
	call vpudraw(x,z)
	x = -0.5*dx
	z = -dz
	call vpudraw(x,z)
	x = 0.
	z = 0.
	call vpudraw(x,z)

	do iary = 1,nary
	   ary0(iary) = 0.
	chk0 = 0

	call vpwppnt1(nary,0,za,xa,zb,xb,va,vb,v0,arya,aryb,_
	              ary0,chk0)

# draw nodes
	x = -dx
	z = 0.
	do iarray = 1,narray
	{
	   theta = (iarray-1)*8*atan(1.)/(narray-1)
	   xx(iarray) = x+0.01*zxrange*sin(theta)
	   zz(iarray) = z+0.01*zxrange*cos(theta)
	}
	call vpcolor(7)
	call vpufill(xx,zz,narray)
	call vpcolor(5)
	fat = 4*plotfat
	call vpfat(fat)
	call vpupline(xx,zz,narray)

	x = -0.5*dx
	z = -dz
	do iarray = 1,narray
	{
	   theta = (iarray-1)*8*atan(1.)/(narray-1)
	   xx(iarray) = x+0.01*zxrange*sin(theta)
	   zz(iarray) = z+0.01*zxrange*cos(theta)
	}
	call vpcolor(7)
	call vpufill(xx,zz,narray)
	call vpcolor(5)
	fat = 4*plotfat
	call vpfat(fat)
	call vpupline(xx,zz,narray)
	x = 0.
	z = 0.
	do iarray = 1,narray
	{
	   theta = (iarray-1)*8*atan(1.)/(narray-1)
	   xx(iarray) = x+0.01*zxrange*sin(theta)
	   zz(iarray) = z+0.01*zxrange*cos(theta)
	}
	call vpcolor(0)
	call vpufill(xx,zz,narray)
	call vpcolor(3)
	fat = 4*plotfat
	call vpfat(fat)
	call vpupline(xx,zz,narray)
	x = -0.193844
	z = 0.455585
	do iarray = 1,narray
	{
	   theta = (iarray-1)*8*atan(1.)/(narray-1)
	   xx(iarray) = x+0.004*zxrange*sin(theta)
	   zz(iarray) = z+0.004*zxrange*cos(theta)
	}
	call vpcolor(7)
	call vpufill(xx,zz,narray)
	x = 0.149067
	z = -0.652885
	do iarray = 1,narray
	{
	   theta = (iarray-1)*8*atan(1.)/(narray-1)
	   xx(iarray) = x+0.004*zxrange*sin(theta)
	   zz(iarray) = z+0.004*zxrange*cos(theta)
	}
	call vpcolor(7)
	call vpufill(xx,zz,narray)

	x = -0.193844+0.008*zxrange
	z = 0.455585+0.002*zxrange
	do iarray = 1,narray
	{
	   theta = (iarray-1)*8*atan(1.)/(narray-1)
	   xx(iarray) = x+0.004*zxrange*sin(theta)
	   zz(iarray) = z+0.004*zxrange*cos(theta)
	}
	call vpcolor(7)
	call vpufill(xx,zz,narray)
	x = 0.149067+0.012*zxrange
	z = -0.652885+0.003*zxrange
	do iarray = 1,narray
	{
	   theta = (iarray-1)*8*atan(1.)/(narray-1)
	   xx(iarray) = x+0.004*zxrange*sin(theta)
	   zz(iarray) = z+0.004*zxrange*cos(theta)
	}
	call vpcolor(7)
	call vpufill(xx,zz,narray)

# write title
        call vpcolor(7)
        call vpfat(titlefat)
        call vptjust(2,1)
        x = xcenter
        z = zmin-0.008*titlesz*zxrange
        call vputext(x,z,titlesz,0,title)

	call vpcolor(7)
        call vpfat(4)
        call vptjust(2,3)
        x = xa-0.04*zxrange
        z = za
        call vputext(x,z,10,0,'a')
        x = xb-0.03*zxrange
        z = zb-0.03*zxrange
        call vputext(x,z,10,0,'b')
        x = 0.04*zxrange
        z = -0.025*zxrange
        call vputext(x,z,10,0,'o')
        call vptjust(3,2)
        x = 0.149067
        z = -0.652995-0.02*zxrange
        call vputext(x,z,10,0,'b\\^\\s60 \\F15 I\\^')
        call vptjust(1,2)
        x = 0.149067+0.03*zxrange
        z = -0.652995-0.01*zxrange
        call vputext(x,z,10,0,'b\\^\\s60 \\F15 II\\^')
        call vptjust(1,5)
        x = -0.193844
        z = 0.455585+0.026*zxrange
        call vputext(x,z,10,0,'a\\^\\s60 \\F15 II\\^')
        call vptjust(2,3)
        x = 0.0745335-0.04*zxrange
        z = -0.3264425-0.02*zxrange
        call vputext(x,z,10,0,'q\\s60 \\_b\\^')
        x = -0.096922-0.04*zxrange
        z = 0.2277925-0.02*zxrange
        call vputext(x,z,10,0,'q\\s60 \\_a\\^')
	call vptfont(-1,-1,2)
        call vptjust(3,5)
        x = -0.193844-0.024*zxrange
        z = 0.455585+0.01*zxrange
        call vputext(x,z,10,0,'a\\^\\s60 \\F15 I\\^')
        call vptjust(1,5)
        x = 0.0745335+0.03*zxrange
        z = -0.3264425-0.02*zxrange
        call vputext(x,z,10,0,'arc\\s60 \\_b\\^')
        x = -0.096922+0.03*zxrange
        z = 0.2277925-0.02*zxrange
        call vputext(x,z,10,0,'arc\\s60 \\_a\\^')
   
# draw a frame
	if(wantframe != 0.)
	{
	   call vpcolor(7)
	   call vpfat(1)
	   call vpumove(xmin,zmin)
	   call vpudraw(xmin,zmax)
	   call vpudraw(xmax,zmax)
	   call vpudraw(xmax,zmin)
	   call vpudraw(xmin,zmin)
	}

stop 
end
